macro_rules! minimal_stack_size {
() => { ... };
}Expand description
Returns the minimum stack size for tasks.
This is the smallest stack size that should be used when creating tasks, typically measured in words (not bytes).
Returns
Minimum stack size in words
Examples
ⓘ
use osal_rs::minimal_stack_size;
let min_stack = minimal_stack_size!();
println!("Minimum stack: {} words", min_stack);