MutexGuard

Struct MutexGuard 

pub struct MutexGuard<'a, T: ?Sized + 'a> { /* private fields */ }
Mutex types and guards for mutual exclusion. RAII guard returned by Mutex::lock().

When this guard goes out of scope, the mutex is automatically unlocked. Provides access to the protected data through Deref and DerefMut.

Examples

use osal_rs::os::{Mutex, MutexFn};
 
let mutex = Mutex::new(0);
 
{
    let mut guard = mutex.lock().unwrap();
    *guard += 1;  // Access protected data
}  // Mutex automatically unlocked here