Queue

Struct Queue 

pub struct Queue { /* private fields */ }
Queue types for inter-task communication. Fixed-capacity FIFO queue of raw, fixed-size byte messages.

See the module-level docs above for a full example.

Implementations

Source

impl Queue

pub fn new(size: UBaseType, message_size: UBaseType) -> Result<Self>

Creates a queue holding up to size messages of message_size bytes each. Fails with Error::InvalidQueueSize if either is 0.

Examples
use osal_rs::os::*;

let queue = Queue::new(4, 4).unwrap();
assert!(Queue::new(0, 4).is_err());
pub fn fetch_with_to_tick( &self, buffer: &mut [u8], time: impl ToTick, ) -> Result<()>

Blocks like Queue::fetch, but accepts any ToTick timeout (e.g. a core::time::Duration) instead of a raw tick count.

Examples
use osal_rs::os::*;
use core::time::Duration;

let queue = Queue::new(2, 1).unwrap();
queue.post(&[9u8], 0).unwrap();

let mut buffer = [0u8];
queue.fetch_with_to_tick(&mut buffer, Duration::from_millis(50)).unwrap();
assert_eq!(buffer, [9]);
pub fn post_with_to_tick(&self, item: &[u8], time: impl ToTick) -> Result<()>

Blocks like Queue::post, but accepts any ToTick timeout (e.g. a core::time::Duration) instead of a raw tick count.

Examples
use osal_rs::os::*;
use core::time::Duration;

let queue = Queue::new(2, 1).unwrap();
queue.post_with_to_tick(&[3u8], Duration::from_millis(50)).unwrap();

let mut buffer = [0u8];
queue.fetch(&mut buffer, 0).unwrap();
assert_eq!(buffer, [3]);

Methods from Deref<Target = QueueHandle>

pub fn is_empty(&self) -> bool

Returns true if this handle is still in its never-initialized (or already-deleted) state, i.e. both the mutex and condition variable are all-zero.

Examples
use osal_rs::os::types::ClockMonotonicHandle;

assert!(ClockMonotonicHandle::default().is_empty());