pub type ThreadFnPtr = dyn Fn(Box<dyn Thread>, Option<ThreadParam>) -> Result<ThreadParam> + Send + Sync + 'static;Expand description
Thread callback function pointer type.
Thread callbacks receive a boxed thread handle and optional parameter, and can return an updated parameter value.