pub type ThreadParam = Arc<dyn Any + Send + Sync>;Expand description
Type-erased parameter that can be passed to thread callbacks.
Allows passing arbitrary data to thread functions in a thread-safe manner.
The parameter can be downcast to its original type using downcast_ref().
Aliased Type
pub struct ThreadParam { /* private fields */ }